@@ -3,17 +3,8 @@ use std::time::Duration;
 use crossbeam::atomic::AtomicCell;
 use tracing::error;
 
-#[macro_export]
-macro_rules! interval_timer {
-    ($name: ident) => {
-        pub struct $name;
-
-        impl IntervalTimerExecutor for $name {
-            fn on_update(&self, _diff: i64) {}
-        }
-    };
-}
-
+// Interval Manager
+#[derive(Debug)]
 pub struct IntervalTimerMgr {
     current: AtomicCell<i64>,
     interval: i64,
@@ -29,7 +20,7 @@ impl IntervalTimerMgr {
     }
 
     /// Update and execute if time passed
-    pub fn update<T>(&self, diff: i64, object: &T)
+    pub fn update<T>(&self, diff: i64, object: &T, container: T::Container)
     where
         T: IntervalTimerExecutor,
     {
@@ -41,7 +32,9 @@ impl IntervalTimerMgr {
             return;
         }
 
-        object.on_update(diff);
+        let diff = self.current.load();
+
+        object.on_update(diff, container);
 
         self.reset();
     }
@@ -62,9 +55,11 @@ impl IntervalTimerMgr {
     }
 }
 
+/// Executed when interval passed
 pub trait IntervalTimerExecutor {
+    type Container;
     /// Executed when interval passed
-    fn on_update(&self, _diff: i64);
+    fn on_update(&self, _diff: i64, container: Self::Container);
 }
 
 #[cfg(test)]
@@ -73,20 +68,19 @@ mod tests {
 
     #[test]
     fn test_update() {
-        interval_timer!(MyMgr);
         let timer = IntervalTimerMgr::new(Duration::from_millis(25));
-        let bu = MyMgr;
-        timer.update(25, &bu);
+        let bu = TestW;
+        timer.update(25, &bu, None);
         assert_eq!(timer.current.load(), 0);
-        timer.update(30, &bu);
+        timer.update(30, &bu, None);
         assert_eq!(5, timer.current.load());
-        timer.update(20, &bu);
+        timer.update(20, &bu, None);
         assert_eq!(0, timer.current.load());
-        timer.update(0, &bu);
+        timer.update(0, &bu, None);
         assert_eq!(0, timer.current.load());
-        timer.update(15, &bu);
+        timer.update(15, &bu, None);
         assert_eq!(15, timer.current.load());
-        timer.update(10, &bu);
+        timer.update(10, &bu, None);
         assert_eq!(0, timer.current.load());
     }
 
@@ -110,4 +104,14 @@ mod tests {
         timer.current.store(0);
         assert!(!timer.is_passed());
     }
+
+    struct TestW;
+
+    impl IntervalTimerExecutor for TestW {
+        type Container = Option<u8>;
+
+        fn on_update(&self, diff: i64, _container: Self::Container) {
+            assert!(diff >= 25)
+        }
+    }
 }
