@@ -10,6 +10,10 @@ cfg_flat_buffers_helpers! {
     pub mod flat_buffers_helpers;
 }
 
+cfg_macros! {
+    pub use rollo_macros;
+}
+
 cfg_game! {
     pub mod game;
 }
